@@ -22,9 +22,7 @@
 #define __IDLE_CONNECTION_H__
 
 #include <glib-object.h>
-#include <telepathy-glib/base-connection.h>
-#include <telepathy-glib/handle.h>
-#include <telepathy-glib/contacts-mixin.h>
+#include <telepathy-glib/telepathy-glib.h>
 
 #include "idle-parser.h"
 
@@ -34,6 +32,7 @@ G_BEGIN_DECLS
 
 typedef struct _IdleConnection IdleConnection;
 typedef struct _IdleConnectionClass IdleConnectionClass;
+typedef struct _IdleConnectionPrivate IdleConnectionPrivate;
 
 struct _IdleConnectionClass {
 	TpBaseConnectionClass parent_class;
@@ -45,6 +44,7 @@ struct _IdleConnection {
 	TpContactsMixin contacts;
 	IdleParser *parser;
 	GQueue *contact_info_requests;
+	IdleConnectionPrivate *priv;
 };
 
 GType idle_connection_get_type(void);
