@@ -17,13 +17,9 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#include "config.h"
 #include "idle-contact-info.h"
 
-#include <telepathy-glib/gtypes.h>
-#include <telepathy-glib/handle-repo.h>
-#include <telepathy-glib/interfaces.h>
-#include <telepathy-glib/util.h>
-
 #define IDLE_DEBUG_FLAG IDLE_DEBUG_CONNECTION
 #include "idle-debug.h"
 #include "idle-muc-channel.h"
