@@ -17,11 +17,11 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#include "config.h"
 #include "idle-debug.h"
 
 #include <stdarg.h>
-#include <telepathy-glib/debug.h>
-#include <telepathy-glib/debug-sender.h>
+#include <telepathy-glib/telepathy-glib.h>
 
 static IdleDebugFlags _flags = 0;
 
@@ -33,6 +33,7 @@ static GDebugKey _keys[] = {
 	{"network", IDLE_DEBUG_NETWORK},
 	{"parser", IDLE_DEBUG_PARSER},
 	{"text", IDLE_DEBUG_TEXT},
+	{"tls", IDLE_DEBUG_TLS},
 	{NULL, 0}
 };
 
