@@ -22,9 +22,7 @@
 #define __IDLE_IM_CHANNEL_H__
 
 #include <glib-object.h>
-#include <telepathy-glib/message-mixin.h>
-#include <telepathy-glib/dbus-properties-mixin.h>
-#include <telepathy-glib/base-channel.h>
+#include <telepathy-glib/telepathy-glib.h>
 
 G_BEGIN_DECLS
 
